@@ -19,11 +19,18 @@
     setdiff(pkgs, doing)
 }
 
+.rRepos <- function(pkgs, invert = FALSE)
+    grep("^(https?://.*|[^/]+)$", pkgs, invert = invert, value=TRUE)
+
+.githubRepos <- function(pkgs) {
+    pkgs <- .rRepos(pkgs, invert = TRUE)
+    grep("^[^/]+/.+", pkgs, value=TRUE)
+}
+
 .reposInstall <-
     function(pkgs, lib, ...)
 {
-    ## non-'github' packages
-    doing <- grep("/", pkgs, invert=TRUE, value=TRUE)
+    doing <- .rRepos(pkgs)
     if (length(doing)) {
         pkgNames <- paste(sQuote(doing), collapse=", ")
         .message("Installing package(s) %s", pkgNames)
@@ -35,7 +42,7 @@
 .githubInstall <-
     function(pkgs, ..., lib.loc=NULL)
 {
-    doing <- grep("/", pkgs, value=TRUE)
+    doing <- .githubRepos(pkgs)
     if (length(doing)) {
         pkgNames <- paste(sQuote(doing), collapse=", ")
         .message("Installing github package(s) %s", pkgNames)
@@ -94,7 +101,7 @@
     if (is.logical(suppressUpdates) && suppressUpdates)
         return(invisible(pkgs))
 
-    oldPkgs <- old.packages(lib.loc)
+    oldPkgs <- old.packages(lib.loc, checkBuilt=TRUE)
     if (is.null(oldPkgs))
         return(invisible(pkgs))
 
@@ -116,7 +123,7 @@
                        instlib=instlib),
                    s = update.packages(lib.loc, oldPkgs=oldPkgs, ask=TRUE,
                        instlib=instlib),
-                   n = invisible(pkgs))   
+                   n = invisible(pkgs))
         } else {
             .message("Updating packages '%s'", pkgList)
             update.packages(lib.loc, oldPkgs=oldPkgs, ask=ask, instlib=instlib)
